RaTeXParseAndLayoutIsolateArgs class
Arguments for ratexParseAndLayoutInIsolate (e.g. pass to compute).
- Annotations
Constructors
- RaTeXParseAndLayoutIsolateArgs({required String latex, required bool displayMode, int? colorArgb})
-
const
Properties
- colorArgb → int?
-
32-bit ARGB (opaque black is
0xFF000000). If null, black is used.final - displayMode → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latex → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited