LineItem class
- Inheritance
-
- Object
- DisplayItem
- LineItem
Constructors
- LineItem({required double x, required double y, required double width, required double thickness, required RaTeXColor color})
-
const
-
LineItem.fromJson(Map<
String, dynamic> j) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited