PathItem class
- Inheritance
-
- Object
- DisplayItem
- PathItem
Constructors
-
PathItem({required double x, required double y, required List<
PathCommand> commands, required bool fill, required RaTeXColor color}) -
const
-
PathItem.fromJson(Map<
String, dynamic> j) -
factory
Properties
- color → RaTeXColor
-
final
-
commands
→ List<
PathCommand> -
final
- fill → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → double
-
final
- y → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited