RaTeXColor class

Constructors

RaTeXColor(double r, double g, double b, double a)
const
RaTeXColor.fromJson(Map<String, dynamic> j)
factory

Properties

a double
final
b double
final
g double
final
hashCode int
The hash code for this object.
no setterinherited
r double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFlutterColor() int
Convert to a Flutter Color (32-bit ARGB int).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited